Editor
======

Widgy provides a drag and drop JavaScript editor interface to the tree in the
form of a Django formfield.

.. figure:: _images/interface-example.png
   :scale: 50 %
   :alt: Interface example

The editor is built on Backbone.js and RequireJS to provide a modular and
customizable interface.

.. figure:: _images/form-builder-example.png
   :scale: 50 %
   :alt: Form Builder example
